An approach to interpreting disease-associated human variants using single-cell epigenomics

What can sv_var do?

Identify risk genes, gene sets, and cells related to different stages and diseases.

Infer cell types involved in complex traits and diseases using single-cell epigenomes AND does not rely on any other annotations and other Omics data.